@@ -1,5 +1,5 @@
 #!/bin/bash
-set -x
+
 # only do stuff if tweaker is actually installed
 if ! (dpkg -l tweakr | grep '^ii' >/dev/null 2>&1); then
     echo "tweakr not installed"
@@ -9,7 +9,7 @@ fi
 PROFILE="$1"
 PROFILES=$(gconftool-2 --all-dirs /system/tweakr|cut -d'/' -f4)
 DBUSSET="dbus-send --print-reply --dest='com.nokia.profiled' /com/nokia/profiled com.nokia.profiled.set_value string:general string:\'%s\' string:\'%s\'"
-read
+
 # check if profile exists
 okflag=0
 for p in ${PROFILES}
@@ -26,10 +26,10 @@ if [ ${okflag} -ne 1 ]; then
 fi
 
 # set tweakr profile
-gconftool-2 --set /system/tweakr/current-preset "${PROFILE}" --type=string &>/dev/null
+gconftool-2 --set /system/tweakr/current-preset "${PROFILE}" --type=string
 
 # set all values
-gconftool-2 -a /system/tweakr/"${PROFILE}"|sed 's/^ //'|sed 's/ = /=/'|awk -F'=' "{cmd=sprintf(\"${DBUSSET}\", \$1, \$2);system(cmd)}" &>/dev/null
+gconftool-2 -a /system/tweakr/"${PROFILE}"|sed 's/^ //'|sed 's/ = /=/'|awk -F'=' "{cmd=sprintf(\"${DBUSSET}\", \$1, \$2);system(cmd)}"
 
 # switch to profile general
-dbus-send --print-reply --dest='com.nokia.profiled' /com/nokia/profiled com.nokia.profiled.set_profile string:general &>/dev/null
+dbus-send --print-reply --dest='com.nokia.profiled' /com/nokia/profiled com.nokia.profiled.set_profile string:general
